@@ -143,6 +143,7 @@ void EnterTimezone(char const *tz)
     CurYear  = tm.tm_year + 1900;
 
     DSEToday = DSE(CurYear, CurMon, CurDay);
+
     /* Adjust DSEToday back by a day if midnight in our time zone requires it */
     if (SysTime < LocalSysTime) {
         DSEToday--;
@@ -1264,6 +1265,20 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim)
         check_trigger_function(trig->warn, "WARN");
         check_trigger_function(trig->omitfunc, "OMITFUNC");
     }
+
+    /* Check that TZ looks plausible */
+    if (trig->tz && (*trig->tz != '!')) {
+        warn_if_timezone_bad(trig->tz);
+    }
+
+    /* Remove leading ! from TZ spec */
+    if (trig->tz && *trig->tz == '!') {
+        char *s = (char *) trig->tz;
+        while (*s) {
+            *s = *(s+1);
+            s++;
+        }
+    }
     return OK;
 }
 
