@@ -187,6 +187,7 @@ got_a_fresh_line(void)
 {
     FreshLine = 1;
     WarnedAboutImplicit = 0;
+    ExpressionNodesEvaluatedThisLine = 0;
 }
 
 void set_cloexec(int fd)
@@ -296,6 +297,7 @@ static int ReadLineFromFile(int use_pclose)
 
 #ifdef USE_READLINE
     int read_some = 0;
+    char prompt[64];
 #endif
 
     DynamicBuffer buf;
@@ -314,17 +316,18 @@ static int ReadLineFromFile(int use_pclose)
             char *lin;
             if (should_ignore_line()) {
                 if (read_some) {
-                    lin = readline("Rem...? ");
+                    snprintf(prompt, sizeof(prompt), "%4d: Rem...? ", LineNo+1);
                 } else {
-                    lin = readline("Remind? ");
+                    snprintf(prompt, sizeof(prompt), "%4d: Remind? ", LineNo+1);
                 }
             } else {
                 if (read_some) {
-                    lin = readline("Rem...> ");
+                    snprintf(prompt, sizeof(prompt), "%4d: Rem...> ", LineNo+1);
                 } else {
-                    lin = readline("Remind> ");
+                    snprintf(prompt, sizeof(prompt), "%4d: Remind> ", LineNo+1);
                 }
             }
+            lin = readline(prompt);
             if (lin) {
                 read_some = 1;
                 DBufFree(&buf);
@@ -1005,6 +1008,7 @@ static int IncludeCmd(char const *cmd)
     CachedFile *h;
     char const *fname;
     int old_flag;
+    int stdin_dup, devnull;
 
     got_a_fresh_line();
     clear_callstack();
@@ -1070,6 +1074,21 @@ static int IncludeCmd(char const *cmd)
 
     /* Not found in cache */
 
+    /* Connect stdin to /dev/null */
+    stdin_dup = dup(STDIN_FILENO);
+    if (stdin_dup >= 0) {
+        devnull = open("/dev/null", O_RDONLY);
+        if (devnull >= 0) {
+            if (dup2(devnull, STDIN_FILENO) >= 0) {
+                set_cloexec(stdin_dup);
+            } else {
+                (void) close(stdin_dup);
+                stdin_dup = -1;
+            }
+            (void) close(devnull);
+        }
+    }
+
     /* If cmd starts with !, then disable RUN within the cmd output */
     if (cmd[0] == '!') {
         fp2 = popen(cmd+1, "r");
@@ -1079,6 +1098,10 @@ static int IncludeCmd(char const *cmd)
     if (!fp2) {
         PopFile();
         DBufFree(&buf);
+        if (stdin_dup >= 0) {
+            (void) dup2(stdin_dup, STDIN_FILENO);
+            (void) close(stdin_dup);
+        }
         return E_CANT_OPEN;
     }
     fp = fp2;
@@ -1094,6 +1117,11 @@ static int IncludeCmd(char const *cmd)
     }
     r = CacheFile(fname, 1);
 
+    if (stdin_dup >= 0) {
+        (void) dup2(stdin_dup, STDIN_FILENO);
+        (void) close(stdin_dup);
+    }
+
     DebugFlag = old_flag;
     if (r == OK) {
         fp = NULL;
