@@ -141,6 +141,7 @@ typedef struct {
     int priority;
     int duration_days;           /* Duration converted to days to search */
     int eventstart;              /* Original event start (datetime) */
+    int eventstart_orig;         /* Original event start in TZ (datetime) */
     int eventduration;           /* Original event duration (minutes) */
     int maybe_uncomputable;      /* Suppress "can't compute trigger" warnings */
     int addomit;                 /* Add trigger date to global OMITs */
@@ -152,10 +153,12 @@ typedef struct {
     DynamicBuffer tags;
     char passthru[PASSTHRU_LEN+1];
     TrigInfo *infos;
+    char const *tz;              /* Time Zone */
 } Trigger;
 
 /* A time trigger */
 typedef struct {
+    int ttime_orig;
     int ttime;
     int nexttime;
     int delta;
@@ -226,6 +229,7 @@ typedef Parser *ParsePtr;  /* Pointer to parser structure */
 #define DB_TRANSLATE    0x100
 #define DB_NONCONST     0x200
 #define DB_UNUSED_VARS  0x400
+#define DB_SWITCH_ZONE  0x800
 
 /* Enumeration of the tokens */
 enum TokTypes
@@ -239,8 +243,8 @@ enum TokTypes
   T_Omit, T_OmitFunc, T_Once, T_Ordinal, T_Pop, T_PopFuncs, T_PopVars,
   T_Preserve, T_Priority, T_Push, T_PushFuncs, T_PushVars, T_Rem,
   T_RemType, T_Rep, T_Return, T_Scanfrom, T_Sched, T_Set, T_Skip, T_Tag,
-  T_Through, T_Time, T_Todo, T_Translate, T_UnSet, T_Until, T_Warn, T_WkDay,
-  T_Year
+  T_Through, T_Time, T_Todo, T_Translate, T_Tz, T_UnSet, T_Until, T_Warn,
+  T_WkDay, T_Year,
 };
 
 /* The structure of a token */
